Don't compile the Skia tools for PDK builds.

Change-Id: I9d64a065bf05d76e131b2d0ab73d136ebbae263f
Reviewed-on: https://skia-review.googlesource.com/5746
Reviewed-by: Leon Scroggins <scroggo@google.com>
Commit-Queue: Derek Sollenberger <djsollen@google.com>
diff --git a/platform_tools/android/tests/expectations/Android.mk b/platform_tools/android/tests/expectations/Android.mk
index 861784a..4586a6a 100644
--- a/platform_tools/android/tests/expectations/Android.mk
+++ b/platform_tools/android/tests/expectations/Android.mk
@@ -165,11 +165,14 @@
 include $(BUILD_SHARED_LIBRARY)
 
 #############################################################
-# Build the skia tools
+# Build the skia tools (except in the PDK build)
 #
+ifneq ($(TARGET_BUILD_PDK),true)
 
 # benchmark (timings)
 include $(BASE_PATH)/bench/Android.mk
 
 # diamond-master (one test to rule them all)
 include $(BASE_PATH)/dm/Android.mk
+
+endif # disable for PDK
diff --git a/platform_tools/android/gyp_gen/makefile_writer.py b/platform_tools/android/gyp_gen/makefile_writer.py
index 6641f7f..e60ce5b 100644
--- a/platform_tools/android/gyp_gen/makefile_writer.py
+++ b/platform_tools/android/gyp_gen/makefile_writer.py
@@ -114,14 +114,17 @@
 SKIA_TOOLS = (
 """
 #############################################################
 # Build the skia tools
 #
+ifneq ($(TARGET_BUILD_PDK),true)
 
 # benchmark (timings)
 include $(BASE_PATH)/bench/Android.mk
 
 # diamond-master (one test to rule them all)
 include $(BASE_PATH)/dm/Android.mk
+
+endif # disable for PDK
 """
 )
 
@@ -114,14 +114,17 @@
 """
 #############################################################
-# Build the skia tools
+# Build the skia tools (except in the PDK build)
 #